"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.testCompositionRegistration = exports.TestComposition = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const __1 = require("..");
const testComponents_1 = require("./testComponents");
const enzyme_1 = require("enzyme");
const enzyme_adapter_react_17_1 = tslib_1.__importDefault(require("@wojtekmaj/enzyme-adapter-react-17"));
const { createRegisterableComposition } = __1.getRegistrationCreators();
enzyme_1.configure({ adapter: new enzyme_adapter_react_17_1.default() });
const TestComposition = props => (react_1.default.createElement("div", null,
    react_1.default.createElement("div", null, props.main),
    react_1.default.createElement("div", null, props.sidebar)));
exports.TestComposition = TestComposition;
exports.testCompositionRegistration = createRegisterableComposition()('test-composition', contentAreas => react_1.default.createElement(exports.TestComposition, { main: contentAreas.main, sidebar: contentAreas.sidebar }), (contentArea, { contentAreaRatio = 1 }) => {
    if (contentArea === 'main') {
        return { contentAreaRatio: 0.66 * contentAreaRatio };
    }
    return { contentAreaRatio: 0.32 * contentAreaRatio };
});
it('can pass props to all contained components', () => {
    const layout = __1.LayoutRegistration()
        .registerComponents(registrar => registrar
        .registerComponent(testComponents_1.testComponentRegistration)
        .registerComponent(testComponents_1.testComponent2Registration))
        .registerCompositions(registrar => registrar.registerComposition(exports.testCompositionRegistration));
    const renderers = layout.createRenderers({ services: {} });
    const wrapper = enzyme_1.mount(renderers.renderCompositions(layout.composition({
        type: 'test-composition',
        props: {},
        contentAreas: {
            main: [
                layout.component({
                    type: 'test',
                    props: {},
                }),
            ],
            sidebar: [
                layout.component({
                    type: 'test2',
                    props: {},
                }),
            ],
        },
    })));
    expect(wrapper.find(testComponents_1.TestComponent).props()).toMatchObject({ contentAreaRatio: 0.66 });
    expect(wrapper.find(testComponents_1.TestComponent2).props()).toMatchObject({ contentAreaRatio: 0.32 });
});
it('nested compositions pass additional props to composition', () => {
    const layout = __1.LayoutRegistration()
        .registerComponents(registrar => registrar
        .registerComponent(testComponents_1.testComponentRegistration)
        .registerComponent(testComponents_1.testComponent2Registration))
        .registerCompositions(registrar => registrar.registerComposition(exports.testCompositionRegistration));
    const renderers = layout.createRenderers({ services: {} });
    const wrapper = enzyme_1.mount(renderers.renderCompositions(layout.composition({
        type: 'test-composition',
        props: {},
        contentAreas: {
            main: [
                layout.nestedComposition({
                    type: 'test-composition',
                    props: {},
                    contentAreas: {
                        main: [
                            layout.component({
                                type: 'test',
                                props: {},
                            }),
                        ],
                        sidebar: [],
                    },
                }),
            ],
            sidebar: [
                layout.component({
                    type: 'test2',
                    props: {},
                }),
            ],
        },
    })));
    expect(wrapper.find(testComponents_1.TestComponent).props()).toMatchObject({ contentAreaRatio: 0.66 * 0.66 });
    expect(wrapper.find(testComponents_1.TestComponent2).props()).toMatchObject({ contentAreaRatio: 0.32 });
});
//# sourceMappingURL=compositions.test.js.map