"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const enzyme_adapter_react_17_1 = tslib_1.__importDefault(require("@wojtekmaj/enzyme-adapter-react-17"));
const testComponents_1 = require("./testComponents");
const enzyme_1 = require("enzyme");
const LayoutRegistration_1 = require("../LayoutRegistration");
const get_registration_creators_1 = require("../get-registration-creators");
enzyme_1.configure({ adapter: new enzyme_adapter_react_17_1.default() });
const { createRegisterableComponent } = get_registration_creators_1.getRegistrationCreators();
it('can hook component middleware', () => {
    let middlewareCalled;
    let middlewareProps;
    const layout = LayoutRegistration_1.LayoutRegistration()
        .registerComponents(registrar => registrar
        .registerComponent(testComponents_1.testComponentWithPropsRegistration)
        .registerMiddleware((cp, mp, ms, next) => {
        middlewareCalled = true;
        middlewareProps = mp;
        return next(cp, mp, ms);
    }))
        .registerCompositions(registrar => registrar.registerComposition(testComponents_1.testCompositionWithPropsRegistration));
    const renderer = layout.createRenderers({ services: {} });
    const renderOutput = enzyme_1.mount(renderer.renderComponents(layout.component({
        type: 'testWithTitleProp',
        props: { title: 'test' },
        skipRender: true,
    })));
    expect(middlewareCalled).toBe(true);
    expect(middlewareProps).toMatchObject({ skipRender: true });
    expect(renderOutput.find(testComponents_1.TestComponentWithProps).length).toBe(1);
    expect(renderOutput.text()).toContain('test');
});
it('can hook multiple component middleware', () => {
    let middlewareCalled;
    let middleware2Called;
    let middleware2Props;
    let middleware2ComponentProps;
    let middleware2Services;
    let componenentServices;
    const layout = LayoutRegistration_1.LayoutRegistration()
        .registerComponents(registrar => registrar
        .registerComponent(createRegisterableComponent('testWithTitleProp', (props, services) => {
        componenentServices = services;
        return react_1.default.createElement(testComponents_1.TestComponentWithProps, { title: props.title });
    }))
        .registerMiddleware((props, _, services, next) => {
        middlewareCalled = true;
        if (middleware2Called) {
            throw new Error('middlewares called out of order');
        }
        return next({ ...props, additional: true }, _, {
            ...services,
            services: { serviceValue: true },
        });
    })
        .registerMiddleware((componentProps, middlewareProps, services, next) => {
        middleware2Called = true;
        middleware2ComponentProps = componentProps;
        middleware2Props = middlewareProps;
        middleware2Services = services;
        return next(middleware2ComponentProps, middleware2Props, middleware2Services);
    }))
        .registerCompositions(registrar => registrar.registerComposition(testComponents_1.testCompositionWithPropsRegistration));
    const renderers = layout.createRenderers({ services: { serviceValue: false } });
    const renderOutput1 = enzyme_1.mount(renderers.renderComponents(layout.component({
        type: 'testWithTitleProp',
        props: { title: 'test' },
        skipRender2: true,
    })));
    expect(middlewareCalled).toBe(true);
    expect(middleware2Called).toBe(true);
    expect(middleware2Props).toMatchObject({ skipRender2: true });
    expect(middleware2ComponentProps).toMatchObject({ additional: true });
    expect(middleware2Services).toMatchObject({ services: { serviceValue: true } });
    expect(componenentServices).toMatchObject({ serviceValue: true });
    expect(renderOutput1.find(testComponents_1.TestComponentWithProps).length).toBe(1);
    expect(renderOutput1.text()).toContain('test');
});
it('can hook composition middleware', () => {
    let middlewareCalled;
    let middlewareProps;
    let middlewareNext;
    const layout = LayoutRegistration_1.LayoutRegistration()
        .registerComponents(registrar => registrar.registerComponent(testComponents_1.testComponentWithPropsRegistration))
        .registerCompositions(registrar => registrar
        .registerComposition(testComponents_1.testCompositionWithPropsRegistration)
        .registerMiddleware((_, mp, __, next) => {
        middlewareCalled = true;
        middlewareProps = mp;
        middlewareNext = next;
        return null;
    }));
    const renderers = layout.createRenderers({ services: {} });
    enzyme_1.mount(renderers.renderCompositions(layout.composition({
        type: 'test-composition-with-props',
        contentAreas: {
            main: [
                layout.component({
                    type: 'testWithTitleProp',
                    props: { title: 'Component title' },
                }),
            ],
        },
        props: { compositionTitle: 'Composition title' },
        skipRender: true,
    })));
    expect(middlewareCalled).toBe(true);
    expect(middlewareProps).toMatchObject({ skipRender: true });
    // Verify next() will actually render the component
    const renderOutput = enzyme_1.mount(middlewareNext());
    expect(renderOutput.find(testComponents_1.TestComponentWithProps).length).toBe(1);
    expect(renderOutput.text()).toContain('Component title');
    expect(renderOutput.text()).toContain('Composition title');
});
it('can hook multiple composition middleware', () => {
    let middlewareCalled;
    let middleware2Called;
    let middleware2Props;
    let middleware2ComponentProps;
    let middleware2Next;
    let middleware2Service;
    const layout = LayoutRegistration_1.LayoutRegistration()
        .registerComponents(registrar => registrar.registerComponent(testComponents_1.testComponentWithPropsRegistration))
        .registerCompositions(registrar => registrar
        .registerComposition(testComponents_1.testCompositionWithPropsRegistration)
        .registerMiddleware((props, _, services, next) => {
        middlewareCalled = true;
        if (middleware2Called) {
            throw new Error('middlewares called out of order');
        }
        return next({ ...props, additional: true }, _, {
            ...services,
            services: { serviceAvailable: true },
        });
    })
        .registerMiddleware((componentProps, middlewareProps, service, next) => {
        middleware2Called = true;
        middleware2ComponentProps = componentProps;
        middleware2Props = middlewareProps;
        middleware2Next = next;
        middleware2Service = service;
        return null;
    }));
    const renderers = layout.createRenderers({ services: { serviceAvailable: false } });
    enzyme_1.mount(renderers.renderCompositions(layout.composition({
        type: 'test-composition-with-props',
        contentAreas: {
            main: [
                layout.component({
                    type: 'testWithTitleProp',
                    props: { title: 'Component title' },
                }),
            ],
        },
        props: { compositionTitle: 'Composition title' },
        skipRender2: true,
    })));
    expect(middlewareCalled).toBe(true);
    expect(middleware2Called).toBe(true);
    expect(middleware2Props).toMatchObject({ skipRender2: true });
    expect(middleware2ComponentProps).toMatchObject({ additional: true });
    expect(middleware2Service).toMatchObject({ services: { serviceAvailable: true } });
    // Verify next() will actually render the component
    const renderOutput1 = enzyme_1.mount(middleware2Next());
    expect(renderOutput1.find(testComponents_1.TestComponentWithProps).length).toBe(1);
    expect(renderOutput1.text()).toContain('Composition title');
    // Verify next() will actually render the component
    const renderOutput = enzyme_1.mount(middleware2Next({ compositionTitle: 'Override' }));
    expect(renderOutput.find(testComponents_1.TestComponentWithProps).length).toBe(1);
    expect(renderOutput.text()).toContain('Override');
});
//# sourceMappingURL=middleware-support.test.js.map